<link href="{{ STATIC_URL }}mediabrowser/css/mediabrowser.css" rel="stylesheet" type="text/css" />
<link href="{{ STATIC_URL }}mediabrowser/css/smoothness/jquery-ui-1.10.3.custom.min.css" rel="stylesheet" type="text/css" />
